@@ -2,14 +2,15 @@ import asyncio
 import datetime
 from typing import TYPE_CHECKING, Optional, Type
 
-from sqlalchemy import JSON, Column, Table, Text, select
+from sqlalchemy import JSON, Column, Table, Text, select, text
 from sqlalchemy.exc import MultipleResultsFound
 from sqlalchemy.ext.asyncio import AsyncConnection
+from sqlalchemy.sql import Delete, Insert
 from sqlalchemy.sql.ddl import CreateTable, DropTable
 
 from bungio.http.route import Route
 from bungio.models.base import ClientMixin, custom_define, custom_field
-from bungio.utils import get_now_with_tz
+from bungio.utils import get_now_with_tz, split_list
 
 if TYPE_CHECKING:
     from bungio.models.base import BaseModel, ManifestModel
@@ -103,12 +104,15 @@ class Manifest(ClientMixin):
 
             return await manifest_class.from_dict(data=result, client=self._client, recursive=True)
 
-    async def fetch_all(self, manifest_class: Type["ManifestModel"]) -> list["ManifestModel"]:
+    async def fetch_all(
+        self, manifest_class: Type["ManifestModel"], filter: Optional[str] = None
+    ) -> list["ManifestModel"]:
         """
         Return all models for a specific manifest entry
 
         Args:
             manifest_class: The classes to find in the manifest
+            filter: A sql where clause with which you can filter the results. Example: `filter="CAST(data ->> 'itemType' AS INTEGER) = 3"` to get only weapons from `DestinyInventoryItemDefinition`
 
         Returns:
             The manifest information, if found
@@ -125,6 +129,9 @@ class Manifest(ClientMixin):
         # get the data
         async with self._client.manifest_storage.begin() as db:
             query = select(self.__saved_manifests[name].columns.data)
+            if filter:
+                query = query.filter(text(filter))
+
             results = await db.execute(query)
             results = results.scalars().all()
 
@@ -159,8 +166,9 @@ class Manifest(ClientMixin):
                         self._client._metadata,
                         Column("reference_id", Text, nullable=False, primary_key=True),
                         Column("data", JSON, nullable=False),
+                        keep_existing=True,
                     )
-                    await db.execute(CreateTable(self.__saved_manifests[manifest_class]))
+                    await db.execute(CreateTable(self.__saved_manifests[manifest_class], if_not_exists=True))
 
                     # fill the table
                     raw_data = await self._client.http.request(
@@ -168,7 +176,8 @@ class Manifest(ClientMixin):
                     )
                     to_insert = [{"reference_id": str(key), "data": data} for key, data in raw_data.items()]
 
-                    await db.execute(self.__saved_manifests[manifest_class].insert(), to_insert)
+                    for part in split_list(to_split=to_insert, chunk_size=500):
+                        await db.execute(Insert(self.__saved_manifests[manifest_class], values=part))
 
     async def _check_for_updates(self):
         """
@@ -180,9 +189,18 @@ class Manifest(ClientMixin):
 
         now = get_now_with_tz()
         async with self.__manifest_lock:
-            if self.__manifest_last_update is None or self.__manifest_last_update < (now - datetime.timedelta(hours=1)):
+            if (
+                self.__manifest_last_update is None
+                or self.__manifest_urls == {}
+                or self.__manifest_last_update < (now - datetime.timedelta(hours=1))
+            ):
                 manifest = await self._client.api.get_destiny_manifest()
 
+                # set the urls
+                self.__manifest_urls = {}
+                for name, url in manifest.json_world_component_content_paths[self._client.language.value].items():
+                    self.__manifest_urls[name] = url
+
                 async with self._client.manifest_storage.begin() as db:
                     res = await db.execute(self.__version_table.select())
                     version = res.scalars().first()
@@ -194,17 +212,12 @@ class Manifest(ClientMixin):
                         self.__saved_manifests = {}
 
                         # update version
-                        await db.execute(self.__version_table.delete())
-                        await db.execute(self.__version_table.insert().values(version=manifest.version))
-
-                        # set the urls
-                        self.__manifest_urls = {}
-                        for name, url in manifest.json_world_component_content_paths[
-                            self._client.language.value
-                        ].items():
-                            self.__manifest_urls[name] = url
+                        await db.execute(Delete(self.__version_table))
+                        await db.execute(Insert(self.__version_table, values={"version": manifest.version}))
 
                         # dispatch the update event
-                        asyncio.create_task(self._client.on_manifest_update())
+                        task = asyncio.create_task(self._client.on_manifest_update())
+                        self._client._tasks.add(task)  # noqa
+                        task.add_done_callback(self._client._tasks.discard)  # noqa
 
             self.__manifest_last_update = now
