@@ -1,11 +1,10 @@
-import attr
-
+from bungio.models.base import custom_define, custom_field
 from bungio.models.mixins import DestinyClanMixin
 
 __all__ = ("DestinyClan",)
 
 
-@attr.define
+@custom_define()
 class DestinyClan(DestinyClanMixin):
     """
     A representation of a Destiny 2 clan
@@ -14,4 +13,4 @@ class DestinyClan(DestinyClanMixin):
         group_id: The clan's id
     """
 
-    group_id: int = attr.field()
+    group_id: int = custom_field()
